#!/bin/zsh

### parameter setting
# grid region east/west/south/north
#region=0:00/360:00/-10:00/85:00
region=0:00/360:00/-80:00/10:00
# map projection and scale
proj=M20		
# boundary tick info
ticks=a10f10g10	

# boundary frame info
#frame=WSne+tNorth_hemisphere 
frame=WSne+tSouth_hemisphere 

# color table min/maz/interval
climit=-8000/0/10	
# contour interval
cint=500			
# contour min/max
limit=-8000/-0       
# conlor table
cptfile=haxby_area.cpt	
# shade direction
light=0/90      

# output postscript file name
#psfile=North_hemisphere.ps
psfile=Sourth_hemisphere.ps
backgrdsamp=ETOPO1_Ice_g_gmt4.grd

# textsize, font, color, justification
textfont="+f12p,Helvetica,-=0.5p,blue+jBL" 


### Main commands
### Main commands
if [ ! -e $backgrdsamp ];then
  echo "Gridfile", $backgrdsamp, " not exists."
  echo "Dowload this file from https://www.ngdc.noaa.gov/mgg/global/relief/ETOPO1/data/ice_surface/grid_registered/netcdf/"
  exit
fi

# making color table
gmt makecpt -Chaxby -T$climit -Z > $cptfile
# making shade file. -V prints out errors.
gmt grdgradient $backgrdsamp -A$light -G$intfile -Ne0.6 -V  # shade
gmt grdimage $backgrdsamp -R$region -J$proj -C$cptfile -I$intfile -K -V > $psfile # shade
# gmt grdimage $backgrdsamp -R$region -J$proj -C$cptfile  -K -V > $psfile
gmt grdcontour $backgrdsamp -R$region -J$proj -C$cint -L$limit -W0.1 -K -O -V  >> $psfile
gmt pscoast -R$region -J$proj -Df -Ggray -W0.1,black -K -V -O >> $psfile
gmt psscale -D5/-1/10/0.5h -C$cptfile -Bf1000a2000 -K -O >> $psfile

gmt psbasemap -R$region -J$proj -B$ticks -B$frame  -O -V >> $psfile

